@@ -308,11 +308,6 @@ impl ComputedProps {
         T: StmtLike + VisitWith<ShouldWork> + FoldWith<Self> + FoldWith<ObjectLitFolder>,
         Vec<T>: VisitWith<ShouldWork>,
     {
-        // Fast path when there's no computed properties.
-        if !contains_computed_expr(&stmts) {
-            return stmts;
-        }
-
         // let stmts = stmts.fold_children_with(self);
         let mut buf = Vec::with_capacity(stmts.len());
 
